@@ -40,33 +40,9 @@ def quote_user_host(user, host):
     return quoted.replace('.', '%2e')
 
 
-class Paginated(object):
-    """Pretends to be a list if you iterate over it, but also keeps a
-       next property you can use to get the next page of data.
-    """
+class Paginated(list):
 
     def __init__(self, items=[], next_marker=None, links=[]):
-        self.items = items
+        super(Paginated, self).__init__(items)
         self.next = next_marker
         self.links = links
-
-    def __len__(self):
-        return len(self.items)
-
-    def __iter__(self):
-        return self.items.__iter__()
-
-    def __getitem__(self, key):
-        return self.items[key]
-
-    def __setitem__(self, key, value):
-        self.items[key] = value
-
-    def __delitem__(self, key):
-        del self.items[key]
-
-    def __reversed__(self):
-        return reversed(self.items)
-
-    def __contains__(self, needle):
-        return needle in self.items
