@@ -19,9 +19,8 @@
 Exception definitions
 """
 
-# flake8: noqa
 # alias exceptions from apiclient for users of this module
-from troveclient.openstack.common.apiclient.exceptions import *
+from troveclient.openstack.common.apiclient.exceptions import *  # noqa
 
 
 class NoTokenLookupException(Exception):
